<?php
/**
 * @package SiteTree Pro
 * @copyright Copyright 2020 Luigi Cavalieri.
 * @license https://opensource.org/licenses/GPL-3.0 GPL v3.0
 *
 *
 *
 * @since 4.5
 */
final class SiteTreeShortcodeController {
    /**
     * @since 4.5
     * @var object
     */
    private $plugin;

    /**
     * @since 4.5
     * @var array
     */
    private $contentTypes;

    /**
     * @since 4.5
     * @var array
     */
    private $postTypes;

    /**
     * @since 4.5
     * @var array
     */
    private $defaults;

    /**
     * @since 4.5
     * @param object $plugin
     */
    public function __construct( $plugin ) {
        $this->plugin = $plugin;
    }

    /**
     * @since 4.5
     *
     * @param array $attributes
     * @return string
     */
    public function doShortcode( $attributes ) {
        if (! isset( $attributes['type'] ) ) {
            return '';
        }

        $shortcode_type = $attributes['type'];

        $this->loadContentTypes();

        if (! isset( $this->contentTypes[$shortcode_type] ) ) {
            return '';
        }

        $this->loadDefaults();

        $content_type = $this->contentTypes[$shortcode_type];
        $list_options = shortcode_atts( $this->defaults[$content_type], $attributes, 'sitetree' );

        $builder = $this->plugin->siteTreeBuilder();
        $builder->setDoingShortcode( true );

        return $builder->buildList( $content_type, $list_options );
    }

    /**
     * @since 4.5
     * @return bool
     */
    private function loadContentTypes() {
        if ( $this->contentTypes ) {
            return false;
        }

        $this->contentTypes = array(
            'post'     => 'post',
            'page'     => 'page',
            'category' => 'category',
            'post_tag' => 'post_tag',
            'author'   => 'authors'
        );

        $this->postTypes = array(
            'post' => 'post',
            'page' => 'page'
        );

        $post_types = get_post_types( array( 'public' => true, '_builtin' => false ) );
        $taxonomies = get_taxonomies( array( 'public' => true, '_builtin' => false ) );

        foreach ( $post_types as $post_type ) {
            $this->postTypes[$post_type]    = $post_type;
            $this->contentTypes[$post_type] = $post_type;
        }

        foreach ( $taxonomies as $taxonomy ) {
            $this->contentTypes[$taxonomy] = $taxonomy;
        }

        return true;
    }

    /**
     * @since 4.5
     * @return bool
     */
    private function loadDefaults() {
        if ( $this->defaults ) {
            return false;
        }

        $defaults_for_page = $this->plugin->dataController()->defaultsForPage( 'site_tree', '', true );

        $this->defaults = &$defaults_for_page['site_tree'];

        foreach ( $this->contentTypes as $content_type ) {
            $this->defaults[$content_type]['show_title'] = true;

            if ( isset( $this->postTypes[$content_type] ) ) {
                $this->defaults[$content_type]['exclude']      = '';
                $this->defaults[$content_type]['include_only'] = '';
                $this->defaults[$content_type]['include_globally_excluded'] = false;
            }

            if (! isset( $this->defaults[$content_type]['limit'] ) ) {
                $this->defaults[$content_type]['limit'] = -1;
            }
        }

        return true;
    }
}
?>